DisplayUtil = DisplayUtil or {}

local visibleSize = cc.Director:getInstance():getVisibleSize()
local spriteFrameCache = cc.SpriteFrameCache:getInstance()

DisplayUtil.size               = {width = visibleSize.width, height = visibleSize.height}
DisplayUtil.width              = DisplayUtil.size.width
DisplayUtil.height             = DisplayUtil.size.height

--[[
为结点创建点击事件
--]]
function DisplayUtil.newTouch(target, beginCall, moveCall, endCall)
    local _listener = cc.EventListenerTouchOneByOne:create()    
    _listener:setSwallowTouches(true)   

    if beginCall then
        _listener:registerScriptHandler(beginCall,cc.Handler.EVENT_TOUCH_BEGAN )
    else        
        local function _beginCall(touch, evnet)
            if target:isVisible() and target:getOpacity()>0 then
                local nsp = target:convertToNodeSpace(touch:getLocation());
                local bb
                if target.getSize then
                    bb = cc.rect(0, 0, target:getSize().width, target:getSize().height);
                else
                    bb = cc.rect(0, 0, target:getContentSize().width, target:getContentSize().height);
                end

                if cc.rectContainsPoint(bb, nsp) == true then
                    return true
                end
            end
            return false
        end
        _listener:registerScriptHandler(_beginCall,cc.Handler.EVENT_TOUCH_BEGAN )

    end
    if moveCall then
        _listener:registerScriptHandler(moveCall,cc.Handler.EVENT_TOUCH_MOVED )
    end
    if endCall then
        _listener:registerScriptHandler(endCall,cc.Handler.EVENT_TOUCH_ENDED )
        _listener:registerScriptHandler(endCall,cc.Handler.EVENT_TOUCH_CANCELLED )      
    end

    local eventDispatcher = target:getEventDispatcher()
    eventDispatcher:addEventListenerWithSceneGraphPriority(_listener, target)

    return _listener
end

function DisplayUtil.removeTouch(target)
    local eventDispatcher = target:getEventDispatcher()
    eventDispatcher:removeEventListenersForTarget(target)
end

function DisplayUtil.newFrames(pattern, begin, length, isReversed)
    local frames = {}
    local step = 1
    local last = begin + length - 1
    if isReversed then
        last, begin = begin, last
        step = -1
    end

    for index = begin, last, step do
        local frameName = string.format(pattern, index)
        local frame = spriteFrameCache:getSpriteFrame(_RR(frameName))
        if not frame then
            LOG_ERROR("DisplayUtil.newFrames() - invalid frame, name %s", frameName)
            return
        end

        frames[index] = frame
    end
    return frames
end

function DisplayUtil.setPartScale(imgKey)

    if imgKey == nil then
        return
    end

    local backBgFrame = cc.SpriteFrameCache:getInstance():getSpriteFrame(_RR(imgKey))   
    local backRect = backBgFrame:getRect()
    returnBg1 = cc.Scale9Sprite:createWithSpriteFrame(backBgFrame, cc.rect(backRect.width/2,backRect.height/3*2,2,2))       

    return returnBg1

end
function DisplayUtil.addEffect(obj,effectName,effectNameSec,bRemove,callback,scale)

    local function animationEvent(armatureBack,movementType,movementID)
        if movementType == ccs.MovementEventType.complete then
            if callback ~= nil then
                callback()
            end
            armatureBack:runAction( cc.CallFunc:create( function() armatureBack:removeFromParent() end ) );

        end
    end

    local ascNum = string.str2Asc(effectNameSec)
    local btnCicleActivities = obj:getChildByTag(ascNum)
    if btnCicleActivities ~= nil then
        return 
    end
    local btnCicleActivities = _RA(effectName);
    if scale ~=nil then
        btnCicleActivities:setScale(scale)
    end
    if bRemove ~=nil then
        btnCicleActivities:getAnimation():setMovementEventCallFunc(animationEvent)
    end   

    local sz = obj:getContentSize()
    btnCicleActivities:setPosition( cc.p(sz.width/2,sz.height/2 ) )
    obj:addChild(btnCicleActivities,1,ascNum)
    btnCicleActivities:getAnimation():play(effectNameSec);
end

function DisplayUtil.showEffect(obj,effectName,effectNameSec)
    local ascNum = string.str2Asc(effectNameSec)
    local btnCicleActivities = obj:getChildByTag(ascNum)
    if btnCicleActivities ~= nil then
        btnCicleActivities:setVisible(true)
    end
end
function DisplayUtil.hideEffect(obj,effectName,effectNameSec)
    local ascNum = string.str2Asc(effectNameSec)
    local btnCicleActivities = obj:getChildByTag(ascNum)
    if btnCicleActivities ~= nil then
        btnCicleActivities:setVisible(false)
    end
end

function DisplayUtil.removeEffect(obj,effectName,effectNameSec)
    local ascNum = string.str2Asc(effectNameSec)
    local childByTag = obj:getChildByTag(ascNum)
    if childByTag ~= nil then
        obj:removeChildByTag(ascNum,true)
    end
end

function DisplayUtil.removeAllEffect(obj)
    obj:removeAllChilds()
end


function DisplayUtil.newTilesSprite(filename, rect)
    if not rect then
        -- DisplayUtil.width .height可视区域
        rect = cc.rect(0, 0, DisplayUtil.width, DisplayUtil.height)
    end
    local sprite = cc.Sprite:create(filename, rect)
    if not sprite then
        LOG_ERROR("DisplayUtil.newTilesSprite() - create sprite failure, filename %s", filename)
        return
    end
    --sprite:getTexture():setTexParameters(gl.LINEAR, gl.LINEAR, gl.REPEAT, gl.CLAMP_TO_EDGE);
    --sprite:getTexture():setTexParameters(gl.LINEAR_MIPMAP_NEAREST, gl.LINEAR, gl.REPEAT, gl.REPEAT)
    sprite:getTexture():setTexParameters(gl.LINEAR, gl.LINEAR, gl.REPEAT, gl.REPEAT)
    --CCSpriteExtend.extend(sprite)
    sprite:getTexture():setAliasTexParameters();    
    sprite:getTexture():generateMipmap()

    return sprite
end

--[[
function DisplayUtil.shaperEffect(node, effectType)

end
--]]
function DisplayUtil.shaperEffect(node, effecType, rVal, gVal, bVal, aVal)
    local program = cc.GLProgram:new()
    program:initWithByteArrays(ShaderDef.vshColor.code, string.format(effecType.code, rVal, gVal, bVal, aVal))
    --program:initWithByteArrays(ShaderDef.vshColor.code, effecType.code)

    program:bindAttribLocation(cc.ATTRIBUTE_NAME_POSITION, cc.VERTEX_ATTRIB_POSITION);
    program:bindAttribLocation(cc.ATTRIBUTE_NAME_COLOR, cc.VERTEX_ATTRIB_COLOR);
    program:bindAttribLocation(cc.ATTRIBUTE_NAME_TEX_COORD, cc.VERTEX_ATTRIB_TEX_COORDS);    
    program:link();    
    program:updateUniforms();                   
    node:setShaderProgram(program)
end

function DisplayUtil.addDownArrow()

    local baseui =BaseUI.New()
    baseui:setSize(cc.size(60,30))
    local spriteDown =  cc.Sprite:createWithSpriteFrameName( _RR("StoryAct2_V2.png") )
    baseui:addChild(spriteDown, "spriteDown", "", eWIDGET_RELATIVE_IN_BOTTOM, cc.p(0, 0))       
    local spriteUp =  cc.Sprite:createWithSpriteFrameName( _RR("StoryAct1_V2.png") )
    baseui:addChild(spriteUp, "spriteUp", "", eWIDGET_RELATIVE_OUT_TOP, cc.p(0, -10))       
    local act1 = cc.MoveBy:create(0.5,cc.p(0,-15))
    local act2 = cc.MoveBy:create(0.5,cc.p(0,15))
    local seq = cc.Sequence:create(act1,act2)
    local rep = cc.RepeatForever:create(seq)
    spriteUp:runAction(rep)
    return baseui;

end

-- 太阳光例子效果
-- 前面2个参数:obj[keyName]
-- 左极限为 950
-- 右极限为 3200
function DisplayUtil.createSunLightParticle(obj, keyName, sunHeadName, plistName, px, py, rotateAngle, zorder, scale)
    if obj[keyName]==nil then
        obj[keyName] = cc.Node:create()
        obj[keyName]:setScale(scale or 1)
        obj[keyName]:setPosition(px, py)
        obj:addChild(obj[keyName], zorder or obj:getChildrenCount()+100)
        obj[keyName]:setRotation(rotateAngle)

        local sunHeadSpr = cc.Sprite:create(_RRP(sunHeadName))
        sunHeadSpr:setName("sunHeadSpr")
        sunHeadSpr:setPosition(0, 280)
        obj[keyName]:addChild(sunHeadSpr)
        sunHeadSpr:runAction(cc.RepeatForever:create(cc.RotateBy:create(3, 180)))
    
        local sunLight = createParticleSystemQuad(_PSQ(plistName))
        sunLight:setPositionType(cc.POSITION_TYPE_RELATIVE)
        sunLight:setPosition(0, 0)
        obj[keyName]:addChild(sunLight)
    end
    
end

-- 移除太阳光例子效果
function DisplayUtil.removeSunLightParticle(obj, keyName)
    if obj[keyName] then
        obj[keyName]:getChildByName("sunHeadSpr"):stopAllActions()
        obj[keyName]:removeAllChildren()
        obj:removeChild(obj[keyName])
        obj[keyName]=nil
    end
end

-- 下雨等通用动画
function DisplayUtil.createRainEffect(obj, keyName, key, x, y, beganIdx, endIdx, feq, scale)
    if obj[keyName]~=nil then
        return
    end
    obj[keyName] = cc.Sprite:create()
    obj[keyName]:setPosition(x, y)
    obj:addChild(obj[keyName])
    obj[keyName]:setScale(scale or 1)

    local animation = cc.Animation:create()
    for i=beganIdx, endIdx do
        animation:addSpriteFrameWithFile(_RRP(key..i..".png"))
    end
    animation:setDelayPerUnit(feq)
    local animate = cc.Animate:create(animation)
    obj[keyName]:runAction(cc.RepeatForever:create(animate))
end

-- 移除掉下雨的动画
function DisplayUtil.removeRainEffect(obj, keyName)
    if obj[keyName] then
        obj[keyName]:stopAllActions()
        obj:removeChild(obj[keyName])
        obj[keyName] = nil
    end
end
