function tonum(v, base)
    return tonumber(v, base) or 0
end

function toint(v)
    return math.round(tonum(v))
end

function tobool(v)
    return (v ~= nil and v ~= false)
end

function totable(v)
    if type(v) ~= "table" then v = {} end
    return v
end

function isset(arr, key)
    local t = type(arr)
    return (t == "table" or t == "userdata") and arr[key] ~= nil
end

function clone(object)
    local lookup_table = {}
    local function _copy(object)
        if type(object) ~= "table" then
            return object
        elseif lookup_table[object] then
            return lookup_table[object]
        end
        local new_table = {}
        lookup_table[object] = new_table
        for key, value in pairs(object) do
            new_table[_copy(key)] = _copy(value)
        end
        return setmetatable(new_table, getmetatable(object))
    end
    return _copy(object)
end


function handler(target, method)
    return function(...)
        return method(target, ...)
    end
end

function math.round(num)
    return math.floor(num + 0.5)
end

--[[
无参调用， 产生 （0,1） 之间的浮点随机数； 
只有参数 a， 产生 1-a  或 a-1 之间的整数； 
有两个参数 a， b， 产生 a-b 之间的随机整数，包括 a , b
--]]
function math.randomEX(a, b)	
	if a and b then
		if a == b then
			return a
		elseif a > b then
			return math.random(b, a)
		else
			return math.random(a, b)
		end
	end
	if a then
		if a > 1 then
			return math.random(a)
		else
			return math.random(a, 1)
		end
	end
	if b then
		if b > 1 then
			return math.random(b)
		else
			return math.random(b, 1)
		end
	end
	return math.random()
end

function startHttpRequest(url, callback, mode, bGZip) 
	local reportUrl = nil
	local http = cc.XMLHttpRequest:new()	
	local ret = string.find(url, "?")
	if ret == nil then
		reportUrl = url.."?time="..tostring(os.clock())
	else
		reportUrl = url.."&time="..tostring(os.clock())
	end	
	if DeviceUtil.platform == "ios" then
		reportUrl = reportUrl.."&p=1"
	elseif DeviceUtil.platform == "android" then
		reportUrl = reportUrl.."&p=2"
	else
		reportUrl = reportUrl.."&p=3"
	end
	
	local localVersion = PlatformMgr:ToShell_GetVersion()
	
	if localVersion ~= nil and localVersion ~= "" then 
		reportUrl = reportUrl.."&v="..localVersion
	end
	if mode == nil then
		mode = "GET"
	end
	if bGZip == true then
		http:setRequestHeader("Accept-Encoding" ,"gzip, deflate")
	end
	http.responseType = cc.XMLHTTPREQUEST_RESPONSE_STRING --XMLHTTPREQUEST_RESPONSE_STRING
	http:open(mode, reportUrl)	
	local function _onHttpCallback()			
		if callback then
			callback(http)
		end			
	end
	http:registerScriptHandler(_onHttpCallback)
	http:send()
end



function compareSize(size1, size2)
	if size1.width == size2.width and size1.height == size2.height then
		return true
	end
	return false
end

function comparePoint(p1, p2)
	if p1.x == p2.x and p1.y == p2.y then
		return true
	end
	return false
end

------------------------- 以下方法是自己添加的 --------------------------
statSender = statSender or {}

function statSender:sendBug(path, bugStr, fun, async, platform)
    local info = nil
    
    if platform==3 then
        info = "log=OE5384-111-android_"
    elseif platform==4 or platform==5 then
        info = "log=OE5384-111-ios_"
    else
        info = "log=OE5384-111-win_"
    end

    bugStr = info..(bugStr or "")
    if not path or path == "" then
        return
    end
    if self.lastBugStr ~= bugStr then
        self.lastBugStr = bugStr
    else
        return
    end

    local xhr = cc.XMLHttpRequest:new()
    xhr.responseType = cc.XMLHTTPREQUEST_RESPONSE_JSON
    xhr:open("POST",path, async)
    xhr.timeout = 15
    local function onReady()
        print("get status : "..xhr.status)
        if xhr.status == 200 then
            fun(xhr.response)
        else
            fun(nil)
        end
    end
    xhr:registerScriptHandler(onReady)
    xhr:send(bugStr)
    
end