
--[[
检查路径是否存在
--]]
function io.exists(path)
    local file = io.open(path, "r")
    if file then
        io.close(file)
        return true
    end
    return false
end

--[[
读取路径文件
返回其内容
--]]
function io.readfile(path)
    local file = io.open(path, "r")
    if file then
        local content = file:read("*a")
        io.close(file)
        return content
    end
    return nil
end

--[[
写文件
path：string 路径
content：string 写入内容
mode：文件打开模式 默认为二进制写入
返回成功与否
--]]
function io.writefile(path, content, mode)
    mode = mode or "w+b"
    local file = io.open(path, mode)
    if file then
        if file:write(content) == nil then return false end
        io.close(file)
        return true
    else
        return false
    end
end

--[[
传入路径，返回文件目录，文件名，文件全名，文件扩展名
path：string 路径
--]]
function io.pathinfo(path)
    local pos = string.len(path)
    local extpos = pos + 1
    while pos > 0 do
        local b = string.byte(path, pos)
        if b == 46 then -- 46 = char "."
            extpos = pos
        elseif b == 47 then -- 47 = char "/"
            break
        end
        pos = pos - 1
    end

    local dirname = string.sub(path, 1, pos)
    local filename = string.sub(path, pos + 1)
    extpos = extpos - pos
    local basename = string.sub(filename, 1, extpos - 1)
    local extname = string.sub(filename, extpos)
    return {
        dirname = dirname,
        filename = filename,
        basename = basename,
        extname = extname
    }
end

--[[
返回文件大小
path：string 路径
--]]
function io.filesize(path)
    local size = false
    local file = io.open(path, "r")
    if file then
        local current = file:seek()
        size = file:seek("end")
        file:seek("set", current)
        io.close(file)
    end
    return size
end



local function scandir(directory, stuff)
	local i, t, popen = 0, {}, io.popen
	for filename in popen('ls -a *.'..stuff..'"'..directory..'"'):lines() do  --Linux 
	   i = i + 1
	   t[i] = filename
	end
	return t
end

local function scandirwin(directory, stuff)
    local i, t, popen = 0, {}, io.popen
    for filename in popen('dir "'..directory..'" /b '..'*.'..stuff):lines() do --Windows ， 自己修改dir命令的参数，此为列举目录
       i = i + 1
       t[i] = filename
    end
    return t
end

function io.getDirFile(path, stuff)	
	if DeviceUtil.platform == "windows" then
		return scandirwin("..\\..\\"..path, stuff)
	else
		return scandir(DeviceUtil.tankResPath..path, stuff)
	end
	--[[
   file=scandirwin('./')
   for i=1,#file do
      print("./script/"..file[i])
   end
--]]
end

