-- Log
function LOG_DEBUG(logTag,format,...)
	LogUtil.output("DEBUG",logTag,format,...)
end

function LOG_INFO(logTag,format,...)
	LogUtil.output("INFO",logTag,format,...)
end

function LOG_WARN(logTag,format,...)
	LogUtil.output("WARN",logTag,format,...)
end

function LOG_ERROR(logTag,format,...)
	LogUtil.output("ERROR",logTag,format,...)
end

function _log_to_file(log)
    local time = os.date("%Y-%m-%d_%H-%M", os.time())
    local fileName = string.format("%s%s", device.writablePath, "log_"..tostring(time)..".txt")

    local target = cc.Application:getInstance():getTargetPlatform()
    if target==0 then  -- win Ϊ lua ʽ
        fileName = string.format("%s%s", device.writablePath, "log_"..tostring(time)..".lua")
    end

	ResUpdate.mkDir(DeviceUtil.tankResPath)
	local writefile = io.open(fileName,'ab+')
	if writefile then
		writefile:write(log.."\r\n")
		writefile:close()
    else
        LOG_ERROR("LogUtil","ERROR! io.open... fileName="..fileName);
	end
end

function LOG_FILE(logTag,format,...)
	if GameConfig.Log_Show == false then
		return
	end
	
	local time = os.date("%X", os.time())
	local msg = string.format(format,... )
	local log = string.format("%s > %s .......... tag (%s)\n",time,msg,logTag)
	_log_to_file(log);
end

-- LogUtil ----------------
LogUtil = LogUtil or {}
function LogUtil.getLogLevelN(logLevelName)
	if( logLevelName == "DEBUG" ) then 
		return 1
	elseif ( logLevelName == "INFO" ) then 
		return 2
	elseif ( logLevelName == "WARN" ) then 
		return 3
	elseif ( logLevelName == "ERROR" ) then 
		return 4
	else
		return 1
	end
end
function LogUtil.isExclusive(logTag)

	if( table.getn(GameConfig.Log_Exclusive) < 1 ) then
		return false
	end
	
	local findTag = function( ignoreList , tag )
		for i=1,#ignoreList do
			if( ignoreList[i] == tag ) then  return false end
		end
		return true
	end
	return findTag(GameConfig.Log_Exclusive,logTag)
end
function LogUtil.isLimit(logLevelName)
	local gLogLevel = LogUtil.getLogLevelN( GameConfig.Log_Limit_Level )
	local cLogLevel = LogUtil.getLogLevelN( logLevelName )
	return (cLogLevel < gLogLevel)
end
function LogUtil.isIgnore(logLevelName,logTag)
	local findTag = function( ignoreList , tag )
		for i=1,#ignoreList do
			if( ignoreList[i] == tag ) then  return true end
		end
		return false
	end
	if( logLevelName == "DEBUG" ) then 
		return findTag(GameConfig.Log_Ignore_Debug,logTag)
	elseif ( logLevelName == "INFO" ) then 
		return findTag(GameConfig.Log_Ignore_Info,logTag)
	elseif ( logLevelName == "WARN" ) then 
		return findTag(GameConfig.Log_Ignore_Warn,logTag)
	elseif ( logLevelName == "ERROR" ) then 
		return findTag(GameConfig.Log_Ignore_Error,logTag)
	else
		return findTag(GameConfig.Log_Ignore_Debug,logTag)
	end
end

LogUtil.outputNum = 1;
function LogUtil.output(logLevel,logTag,format,...)
	
	if GameConfig.Log_Show == false then
		return
	end
	if( format == nil ) then
		println( "argument 'format' is not be nil!" )
		println( debug.traceback() )
	end
	if( logTag == nil ) then
		println( "argument 'logTag' is not be nil!" )
		println( debug.traceback() )
	end
	if( LogUtil.isExclusive( logTag ) and logLevel ~= "ERROR" ) then
		println("log:"..logTag.." Exclusive")
		return
	end
	if( LogUtil.isLimit( logLevel ) ) then
		println("log:"..logLevel.." limited")
		return
	end
	if( LogUtil.isIgnore( logLevel,logTag ) ) then
		println("log:"..logTag.." ignore")
		return
	end
	
	local trace = debug.getinfo(3)
	local file = trace.source
	local line = trace.linedefined
	local fun = trace.name
	local time = os.date("%X", os.time())
	
	if (fun == nil) then 
		fun = "<unknown>";
	end
	
	if string.find(file, "\\") then
		file = string.match(file, ".+\\([^\\]*%.%w+)$")
	elseif string.find(file, "/") then
		file = string.match(file, ".+/([^/]*%.%w+)$")
	end
	local msg = nil	
	local function _formatString(...)
        if(not ...)then
            msg = string.format(format,"")
        else
		    msg = string.format(format,...)
        end
	end
	if pcall(_formatString, ...) then
		local log = string.format("TANK@%s [LUA-%-5s] %s %-32s > %s .......... in function '%s' tag (%s)",LogUtil.outputNum,logLevel,time,string.format("%s:%d",file,line),msg,fun,logTag)
		LogUtil.outputNum = LogUtil.outputNum + 1;		
		println( logLevel, log )
		return
	end
	
	local log = string.format("%s %d %s arg is nil", file, line, tostring(format))	
	println( "ERROR", log )
    --_log_to_file(log);
end