--时间函数
TimeUtil = TimeUtil or {}

-- 时间计时器
--[[
	scheduleStart (执行函数，执行时间间隔) 先停timeInterval后再执行函数
	scheduleStop (执行函数) 停止执行函数
	
	exam:
	local time = nil
	local function anticlockwiseUpdate()
		do something...
		if (stop)
			TimeUtil.scheduleStop(time)
	end									
	time = TimeUtil.scheduleStart(anticlockwiseUpdate, 1)
--]]
function TimeUtil.scheduleStart(luaFunction, timeInterval, bImmediate)
	if TimeUtil.tickIdTable == nil then
		TimeUtil.tickIdTable = {}
	end
	local id = cc.Director:getInstance():getScheduler():scheduleScriptFunc(luaFunction, timeInterval, false)
	table.insert(TimeUtil.tickIdTable, id)
    if bImmediate == true then
        luaFunction(0)
    end
	return id;
end	

function TimeUtil.scheduleStop(scheduleId)
	if scheduleId ~= nil then
		cc.Director:getInstance():getScheduler():unscheduleScriptEntry(scheduleId)
		table.removeItem(TimeUtil.tickIdTable, scheduleId)
		scheduleId = nil
	end
end

function TimeUtil.scheduleStopAll()	
	if TimeUtil.tickIdTable then
		for k,v in pairs(TimeUtil.tickIdTable) do		
			cc.Director:getInstance():getScheduler():unscheduleScriptEntry(v)		
		end
	end
	TimeUtil.tickIdTable = {}
end

--游戏启动，看到登录界面后才可以调用这个方法
function TimeUtil.delayCallback(delayTime, callback)
	if GameWorld and GameWorld:getUIMgr() then
		local action = cc.Sequence:create(					
					cc.DelayTime:create(delayTime),
					cc.CallFunc:create( callback ))		
				
		GameWorld:getUIMgr():getRootNode():runAction(action)
	else
		LOG_WARN("TimeUtil", "delayCallback fail")
	end	
end
--获取系统时间
--[[
	getSystemTime():返回时间数值，1970年1月1日00:00距今时间，单位为秒
	getSystemDate():返回日期字符串
	getSystemDate(formate):返回指定格式的日期字符串	格式有
		%a abbreviated weekday name (e.g., Wed)
		%A full weekday name (e.g., Wednesday)
		%b abbreviated month name (e.g., Sep)
		%B full month name (e.g., September)
		%c date and time (e.g., 09/16/98 23:48:10) 
		%d day of the month (16) [01-31]
		%H hour, using a 24-hour clock (23) [00-23]
		%I hour, using a 12-hour clock (11) [01-12]
		%M minute (48) [00-59]
		%m month (09) [01-12]
		%p either "am" or "pm" (pm)
		%S second (10) [00-61]
		%w weekday (3) [0-6 = Sunday-Saturday]
		%x date (e.g., 09/16/98)
		%X time (e.g., 23:48:10)
		%Y full year (1998)
		%y two-digit year (98) [00-99]
		%% the character '%'
	getSystemClock():返回执行程序花去的时间数值，单位为秒	
--]]
function TimeUtil.getSystemTime()
	return os.time()
end
function TimeUtil.getSystemDate()
	return os.date()
end
function TimeUtil.getSystemDate(formate)
	return os.date(formate, os.time())
end
function TimeUtil.getSystemClock()
	return os.clock()
end

--输出时间的格式化字符串 32456 =>54m56s 
function TimeUtil.formatTime(value, bAll)
	if type(value) == "number" then
		if value < 0 then
			value = 0
		end
		local d = 0
		local h, temp = math.modf(value/3600)
		d = math.modf(h/24)
		h = h-(d*24)
		temp = temp * 3600
		local m = math.modf(temp/60.0)
		local s = value%60 
		if bAll then
			return string.format("%02dd%02dh%02dm%02ds", d, h, m, s)
		end
		if d > 0 then
			return string.format("%02dd%02dh", d, h)		
		elseif h > 0 then
			return string.format("%02dh%02dm", h, m)
		else
			return string.format("%02dm%02ds", m, s)		
		end
	end	
end
--旧		
--输出时间的格式化字符串 输入1970年到现在的秒数 =>HH:MM
function TimeUtil.formatTimeByNow(value)
	local secInday = math.mod(value,60*60*24)
	local hour = math.floor(secInday/(60*60))
	local min = math.floor(math.floor(secInday/60)/60)
	return string.format("%2d:%2d", hour, min)
end


--新
--输出时间的格式化字符串 输入1970年到现在的秒数 =>HH:MM
function TimeUtil.formatDateForHMS(seconds, dateformat)
   
     seconds = tonumber(seconds)
     dateformat = dateformat or "%H:%M:%S"			      
     return os.date(dateformat, seconds)
	
 end


function TimeUtil.formatDateForYMD(seconds, dateformat)
     
     seconds = tonumber(seconds)
     dateformat = dateformat or "%Y/%m/%d"		      
     return os.date(dateformat, seconds)
 end

function TimeUtil.formatDateForYMDHM(seconds, dateformat)
     
     seconds = tonumber(seconds)
     dateformat = dateformat or "%Y/%m/%d(%H:%M)"		      
     return os.date(dateformat, seconds)
 end

function TimeUtil.formateDateForMDHM(seconds,dataformat)
	 seconds = tonumber(seconds)
     dateformat = dateformat or "%m-%d %H:%M"		      
     return os.date(dateformat, seconds)
end

function TimeUtil.formatDateForHM(seconds,dataformat)
	 seconds = tonumber(seconds)
     dateformat = dateformat or "%H:%M"		      
     return os.date(dateformat, seconds)
end

function TimeUtil.formatYMDForData(srcDateTime)
	local Y = string.sub(srcDateTime,1,4)  
    local M = string.sub(srcDateTime,6,7)  
    local D = string.sub(srcDateTime,9,10)  
     --把日期时间字符串转换成对应的日期时间  
    local time = os.time{year=Y, month=M, day=D, hour=00,min=00,sec=00}  
	return time	
end